@@ -203,6 +203,7 @@ class TalosProducer(object):
                 self.partitionSenderMap.get(partitionId).add_message(userMessageList)
         except Exception as e:
             self.logger.error("add_user_message func error: " + traceback.format_exc())
+            raise e
         finally:
             self.add_user_messageLock.release()
 
@@ -250,6 +251,7 @@ class TalosProducer(object):
                 self.partitionSenderMap.get(partitionId).add_message(value)
         except Exception as e:
             self.logger.error("do_add_user_message func error: " + traceback.format_exc())
+            raise e
         finally:
             self.do_add_user_messageLock.release()
 
@@ -259,7 +261,11 @@ class TalosProducer(object):
                                                     self.updatePartitionIdMsgNumber)
 
     def check_message_partition_key_validity(self, partitionKey=None):
-        assert not partitionKey
+        try:
+            assert not partitionKey
+        except AssertionError as e:
+            raise e
+
         if len(partitionKey) < self.partitionKeyMinLen or len(partitionKey) > self.partitionKeyMaxLen:
             raise InvalidArgumentError("Invalid partition key which length must be at "
                                        + "least " + str(self.partitionKeyMinLen) +
